#
# spec file for package icinga
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1230
%define using_systemd 1
%else
%define using_sysvinit 1
%endif

Name:           icinga
Version:        1.14.0
Release:        1.5

Summary:        Host/service/network monitoring program
License:        GPL-2.0
Group:          System/Monitoring
Url:            http://www.icinga.org/
Source0:        https://github.com/Icinga/icinga-core/archive/v%{version}.tar.gz
Source1:        rc%{name}
Source2:        rcido2db
Source3:        %{name}.sysconfig
Source4:        suse.de-%{name}
Source5:        icinga-rpmlintrc
Source6:        icinga.8
Source7:        icingastats.8
Source8:        ido2db.8
Source9:        mini_epn_icinga.8
Source10:       README.SUSE
Source11:       README.SUSE.idoutils
Source12:       update_icinga_paths.sh
Source14:       new_mini_epn.8
Source15:       mini_epn.8
Source16:       log2ido.8
Source17:       icinga-favicon.ico
Source18:       icinga-exec-start-pre
Source19:       ido2db-exec-start-pre
# PATCH-FIX-OPENSUSE icinga-workaround-131-apache-conf-issue.patch
Patch0:         icinga-workaround-131-apache-conf-issue.patch
# PATCH-FIX-OPENSUSE icinga-fix-systemd-services.patch
Patch1:         icinga-fix-systemd-services.patch
# PATCH-FIX-UPSTREAM icinga-1.11.7-fix-bashisms.patch ledest@gmail.com
Patch2:         icinga-1.11.7-fix-bashisms.patch
Provides:       monitoring_daemon
BuildRequires:  apache2-devel
BuildRequires:  nagios-rpm-macros >= 0.10
%if 0%{?suse_version} >= 1110
BuildRequires:  fdupes
%endif
%if 0%{?suse_version} > 1310
BuildRequires:  util-linux-systemd
%endif
BuildRequires:  freetype2-devel
BuildRequires:  gd-devel > 1.8
BuildRequires:  iputils
BuildRequires:  krb5-devel
BuildRequires:  libdbi-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libopenssl-devel
BuildRequires:  libpng-devel
BuildRequires:  mailx
BuildRequires:  net-snmp-devel
BuildRequires:  net-tools
BuildRequires:  openssl
BuildRequires:  pcre-devel
BuildRequires:  zlib-devel
%if 0%{?using_systemd}
BuildRequires:  systemd
Source100:      icinga_sysvinit_compat
%endif
Requires:       net-tools
Requires(pre):  %fillup_prereq
Requires(pre):  %insserv_prereq
Requires(pre):  /bin/logger
Requires(pre):  fileutils
Requires(pre):  gawk
Requires(pre):  grep
Requires(pre):  pwdutils
Requires(pre):  sed
%if 0%{?suse_version} < 1140
Requires:       perl = %{perl_version}
%else
%{perl_requires}
%endif
%{?libperl_requires}
%if 0%{?using_systemd}
%{?systemd_requires}
%endif
Requires:       mailx
Recommends:     monitoring-tools
Recommends:     %{name}-plugins-eventhandlers
Recommends:     %{name}-www
Recommends:     cron
Recommends:     logrotate
Recommends:     nagios-plugins
Recommends:     net-snmp
Recommends:     openssl
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%define         apacheconfdir  %{_sysconfdir}/apache2/conf.d
%define         apachegroup    www
# Macro that print mesages to syslog at package (un)install time
%define         logmsg logger -t %{name}/rpm

%description
Icinga is a program that will monitor hosts and services on your
network. It has the ability to email or page you when a problem arises
and when a problem is resolved. Icinga is written in C and is
designed to run under Linux (and some other *NIX variants) as a
background process, intermittently running checks on various services
that you specify.

The actual service checks are performed by separate "plugin" programs
which return the status of the checks to Icinga. The plugins are
available at http://sourceforge.net/projects/icingaplug

This package provide core programs for icinga. The web interface,
documentation, and development files are built as separate packages

%package www
Summary:        Provides the HTML and CGI files for the Icinga web interface
Group:          System/Monitoring
Provides:       %{name}-classicui
Provides:       monitoring_webfrontend
Requires:       %{name}-classicui-config = %{version}
Requires:       %{name}-doc = %{version}
Requires(pre):  apache2

%description www
Icinga is a program that will monitor hosts and services on your
network. It has the ability to email or page you when a problem arises
and when a problem is resolved. Icinga is written in C and is
designed to run under Linux (and some other *NIX variants) as a
background process, intermittently running checks on various services
that you specify.

Several CGI programs are included with Icinga in order to allow you
to view the current service status, problem history, notification
history, and log file via the web. This package provides the HTML and
CGI files for the Icinga web interface. In addition, HTML
documentation is included in this package

%package www-config
Summary:        Classic UI configuration for %{name}
Group:          System/Monitoring
Provides:       %{name}-classicui-config
Conflicts:      icinga2-classicui-config
Requires(pre):  apache2

%description www-config
This packages contains the classic ui configuration for %{name}.

%package devel
Summary:        Provides include files that Icinga-related applications may compile against
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
Icinga is a program that will monitor hosts and services on your
network. It has the ability to email or page you when a problem arises
and when a problem is resolved. Icinga is written in C and is
designed to run under Linux (and some other *NIX variants) as a
background process, intermittently running checks on various services
that you specify.

This package provides include files that Icinga-related applications
may compile against.

%package -n monitoring-tools
Summary:        Provides mini_epn for Icinga and Nagios
Group:          System/Monitoring
Requires:       monitoring_daemon
Provides:       icinga-monitoring-tools = %{version}-%{release}
Obsoletes:      icinga-monitoring-tools < %{version}-%{release}
%if 0%{?suse_version} < 1140
Requires:       perl = %{perl_version}
%else
%{perl_requires}
%endif

%description -n monitoring-tools
This package provides the programs mini_epn and new_mini_epn
for Icinga and Nagios.

%package idoutils
Summary:        Provides the IDOUtils functionality for Icinga
Group:          System/Monitoring
Requires:       %{name}-idoutils-drivers-dbd >= %{version}
Requires(pre):  %{name} = %{version}

%description idoutils
Icinga is a program that will monitor hosts and services on your
network. It has the ability to email or page you when a problem arises
and when a problem is resolved. Icinga is written in C and is
designed to run under Linux (and some other *NIX variants) as a
background process, intermittently running checks on various services
that you specify.

This package provides the IDOUtils extensions for Icinga

%package idoutils-mysql
Summary:        IDOUtils drivers for MySQL
Group:          System/Monitoring
Requires:       %{name}-idoutils = %{version}
Requires:       libdbi-drivers-dbd-mysql
Requires:       perl(DBD::mysql)
Recommends:     mysql
Recommends:     mysql-client
Provides:       %{name}-idoutils-drivers-dbd = %{version}
Conflicts:      idoutils-oracle
Conflicts:      idoutils-pgsql

%description idoutils-mysql
This package requires all needed packages for using IDOUtils with MySQL.

%package idoutils-oracle
Summary:        IDOUtils drivers for Oracle
Group:          System/Monitoring
Requires:       %{name}-idoutils = %{version}
Recommends:     oracle-client
Provides:       %{name}-idoutils-drivers-dbd = %{version}
Conflicts:      idoutils-pgsql
Conflicts:      idoutils-mysql

%description idoutils-oracle
This package requires all needed packages for using IDOUtils with OracleDB.

%package idoutils-pgsql
Summary:        IDOUtils drivers for PostgreSQL
Group:          System/Monitoring
Requires:       %{name}-idoutils = %{version}
Requires:       libdbi-drivers-dbd-pgsql
Recommends:     postgresql
Recommends:     postgresql-libs
Provides:       %{name}-idoutils-drivers-dbd = %{version}
Conflicts:      idoutils-mysql
Conflicts:      idoutils-oracle

%description idoutils-pgsql
This package requires all needed packages for using IDOUtils with PostgreSQL.

%package doc
Summary:        Online documentation for %{name}
Group:          System/Monitoring
Recommends:     %{name}-web = %{version}

%description doc
This package provides the online documentation for %{name}.

%package plugins-eventhandlers
Summary:        Eventhandlers for %{name}
Group:          System/Monitoring
Recommends:     %{name} = %{version}

%description plugins-eventhandlers
Eventhandlers for %{name}. Providing different scripts for distributed
monitoring, redundancy and disabling and enabling service checks and
notifications.

%package plugins-downtimes
Summary:        Recurring Downtimes Management for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}
Requires:       perl-Date-Calc

%description plugins-downtimes
Provides scripts to manage recurring downtimes for %{name}.
http://docs.icinga.org/latest/en/recurring_downtimes.html

%prep
%setup -q -n icinga-core-%{version}
%if 0%{?suse_version} == 1310
%patch0 -p1
%endif
%patch1 -p1
%patch2 -p1

%build
export PATH_TO_TRACEROUTE="%{_sbindir}/traceroute"
%configure \
    --prefix="%{icinga_datadir}" \
    --exec-prefix="%{_sbindir}" \
    --bindir="%{_sbindir}" \
    --datadir="%{icinga_datadir}" \
    --datarootdir="%{icinga_datadir}" \
    --libexecdir="%{icinga_plugindir}" \
    --localstatedir="%{icinga_localstatedir}"  \
    --libdir="%{icinga_libdir}" \
    --sbindir="%{icinga_cgidir}" \
    --sysconfdir="%{icinga_sysconfdir}" \
    --with-command-user="%{icinga_command_user}" \
    --with-command-group="%{icinga_command_group}" \
    --with-gd-lib="%{_libdir}" \
    --with-gd-inc="%{_includedir}" \
    --with-htmurl="/%{name}" \
    --with-cgiurl="/%{name}/cgi-bin" \
    --with-mainurl="/%{name}/cgi-bin/status.cgi?allunhandledproblems" \
    --with-init-dir="%{_initrddir}" \
    --with-lockfile="%{icinga_lockfile}" \
    --with-icinga-user="%{icinga_user}" \
    --with-icinga-group="%{icinga_group}" \
    --with-httpd-conf="%{apacheconfdir}" \
    --with-log-dir="%{icinga_logdir}" \
    --with-perlcache \
    --enable-cgi-log \
    --enable-event-broker \
    --enable-embedded-perl \
    --enable-idoutils \
    --enable-ssl \
    --with-cgi-log-dir="%{icinga_cgi_logdir}" \
    --with-plugin-dir="%{icinga_plugindir}" \
    --with-eventhandler-dir="%{icinga_eventhandlerdir}" \
    --with-p1-file-dir="%{icinga_datadir}" \
    --with-checkresult-dir="%{icinga_checkresultdir}" \
    --with-ext-cmd-file-dir="%{icinga_cmd_filedir}" \
    --with-http-auth-file="%{icinga_http_authfile}" \
    --with-icinga-chkfile="%{icinga_chkfile}" \
    --with-ido2db-lockfile="%{icinga_ido2db_lockfile}" \
    --with-ido-sockfile="%{icinga_ido2db_socketfile}" \
    --with-idomod-tmpfile="%{icinga_idomod_tmpfile}" \
    --with-state-dir="%{icinga_spooldir}" \
    --with-temp-file="%{icinga_tempfile}" \
    --with-temp-dir="%{icinga_tempdir}"

make %{?_smp_mflags} all

# make daemonchk.cgi and event handlers
pushd contrib 1>/dev/null
for f in `find . -type f` ; do
    sed -i "s=/usr/local/icinga/var/status.dat=%{icinga_spooldir}/status.dat=; \
        s=/usr/local/icinga/var/icinga.lock=%{icinga_ido2db_lockfile}=; \
        s=NscaBin\=\"/usr/local/icinga/libexec/send_nsca\"=NscaBin\=/usr/bin/send_nsca=; \
        s=/usr/local/icinga/libexec/eventhandlers/=%{icinga_eventhandlerdir}/=; \
        s=/usr/local/nagios/libexec/eventhandlers/=%{icinga_eventhandlerdir}/=; \
        s=\$icinga/etc/=%{icinga_sysconfdir}/=; \
        s=/usr/local/icinga/etc/=%{icinga_sysconfdir}/=" ${f}
done
popd 1>/dev/null
make %{?_smp_mflags} -C contrib

%install
make \
    install-unstripped \
%if 0%{?using_systemd}
    install-systemd \
%else
    install-init \
%endif
    install-commandmode \
    install-idoutils \
    install-config \
    install-webconf \
    install-eventhandlers \
    install-downtimes \
    DESTDIR=%{buildroot} \
    INSTALL_OPTS="" \
    INSTALL_OPTS_WEB="" \
    COMMAND_OPTS="" \
    INIT_OPTS=""

make install -C contrib \
    DESTDIR=%{buildroot} \
    INSTALL_OPTS=""

# make SUSE readmes available
cp %{SOURCE10} ./
cp %{SOURCE11} ./

# replace placeholders in the update_icinga_paths.sh script
sed -i "s=%%{logmsg}=%{logmsg}=; \
        s=%%{icinga_lockfile}=%{icinga_lockfile}=; \
        s=%%{icinga_sysconfdir}=%{icinga_sysconfdir}=; \
        s=%%{icinga_eventhandlerdir}=%{icinga_eventhandlerdir}=; \
        s=%%{icinga_spooldir}=%{icinga_spooldir}=; \
        s=%%{icinga_ido2db_lockfile}=%{icinga_ido2db_lockfile}=; \
        s=%%{icinga_ido2db_socketfile}=%{icinga_ido2db_socketfile}=; \
        s=%%{icinga_cmdfile}=%{icinga_cmdfile}=" %{SOURCE12}
# make update_icinga_paths.sh script available
chmod +x %{SOURCE12}
mkdir -p ./examples
cp %{SOURCE12} ./examples

# make unsupported mysql db creation script available
pushd module/idoutils/db 1>/dev/null
mkdir -p examples
cp scripts/create_mysqldb.sh examples/
popd 1>/dev/null

# move idoutils sample configs to final name
mv "%{buildroot}%{icinga_sysconfdir}/ido2db.cfg-sample" "%{buildroot}%{icinga_sysconfdir}/ido2db.cfg"
mv "%{buildroot}%{icinga_sysconfdir}/idomod.cfg-sample" "%{buildroot}%{icinga_sysconfdir}/idomod.cfg"
mv "%{buildroot}%{icinga_sysconfdir}/modules/idoutils.cfg-sample" "%{buildroot}%{icinga_sysconfdir}/modules/idoutils.cfg"

# fix resource.cfg eventhandler path - otherwise it creates problem with the update_config_files script
sed -i "s|/usr/lib/nagios/plugins/eventhandlers|%{icinga_eventhandlerdir}|g" "%{buildroot}%{icinga_sysconfdir}/resource.cfg"

# remove unnecessary files from www log directory
rm "%{buildroot}/%{icinga_cgi_logdir}/"{.htaccess,index.htm}

# remove setuid from %%{icinga_cmd_filedir}
chmod -s "%{buildroot}%{icinga_cmd_filedir}"

# install logrotate rule
install -D -m 0644 icinga.logrotate %{buildroot}%{icinga_logrotatefile}

# install sample htpasswd file
install -D -m 0644 icinga.htpasswd %{buildroot}%{icinga_http_authfile}

# create icinga localstatedir
install -d -m 0755 %{buildroot}%{icinga_localstatedir}

# install eventhandlers
cp -r contrib/eventhandlers/* "%{buildroot}%{icinga_eventhandlerdir}"

# install downtimes (move to previous location)
mv "%{buildroot}%{icinga_plugindir}/downtimes" "%{buildroot}%{icinga_libdir}/"
rm -rf "%{buildroot}/var/lib/nagios"

# install headers for development package
install -d -m0755 "%{buildroot}%{_includedir}/%{name}/"
install -m0644 include/{config,snprintf,cgiutils,locations}.h "%{buildroot}%{_includedir}/%{name}"

# REST of special SUSE stuff here, if needed....
# init-scripts
# remove the default init script as SUSE uses an adapted one
%if 0%{?using_systemd}
install -D -m0755 %{SOURCE100} %{buildroot}%{_sbindir}/rc%{name}
ln -sf /usr/sbin/service %{buildroot}%{_sbindir}/rcido2db
install -D -m0755 %{SOURCE18} "%{buildroot}%{icinga_libdir}/icinga-exec-start-pre"
install -D -m0755 %{SOURCE19} "%{buildroot}%{icinga_libdir}/ido2db-exec-start-pre"
# remove systemd sysconfig file because we use our own
rm "%{buildroot}%{_sysconfdir}/sysconfig/%{name}"
%else
ln -sf ../../%{_initrddir}/%{name} "%{buildroot}%{_sbindir}/rc%{name}"
ln -sf ../../%{_initrddir}/ido2db "%{buildroot}%{_sbindir}/rcido2db"
install -D -m0755 %{SOURCE1} "%{buildroot}%{_initrddir}/%{name}"
install -D -m0755 %{SOURCE2} "%{buildroot}%{_initrddir}/ido2db"
%endif
# sysconfig script
install -D -m 0644 %{SOURCE3} "%{buildroot}%{_localstatedir}/adm/fillup-templates/sysconfig.%{name}"
# install cronjob (gzip' the logfiles)
install -D -m 0640 %{SOURCE4} "%{buildroot}%{_sysconfdir}/cron.weekly/%{name}"
%if 0%{?suse_version} >= 1110
  %fdupes -s %{buildroot}
%endif

# fix documentation
rm "sample-config/"*.in
rm "sample-config/modules/"*.in
rm "sample-config/template-object/"*.in
rm "module/idoutils/config/"*.in

# install manpages from Debian
install -d -m0755 "%{buildroot}%{_mandir}/man8/"
install -m644 %{SOURCE6}  "%{buildroot}%{_mandir}/man8/"
install -m644 %{SOURCE7}  "%{buildroot}%{_mandir}/man8/"
install -m644 %{SOURCE8}  "%{buildroot}%{_mandir}/man8/"
install -m644 %{SOURCE9}  "%{buildroot}%{_mandir}/man8/"
install -m644 %{SOURCE14} "%{buildroot}%{_mandir}/man8/"
install -m644 %{SOURCE15} "%{buildroot}%{_mandir}/man8/"
install -m644 %{SOURCE16} "%{buildroot}%{_mandir}/man8/"

# install favicon.ico
install -m644 %{SOURCE17} "%{buildroot}/%{icinga_datadir}/favicon.ico"

%pre
%if 0%{?using_systemd}
%service_add_pre %{name}.service
%endif
# add icinga user and groups
groupadd -r %{icinga_group} 2>/dev/null || :
groupadd -r %{icinga_command_group} 2>/dev/null || :
/usr/sbin/useradd -c %{icinga_user} -s /sbin/nologin -r -d %{icinga_localstatedir} -G %{icinga_command_group} -g %{icinga_group} %{icinga_user} 2> /dev/null || :

%post
if [ ${1:-0} -gt 1 ]
then
# On Update
    %{_defaultdocdir}/%{name}/examples/update_icinga_paths.sh %{name}
else
# On installation
  # First installation: create an alias for the default nagiosadmin user
  if [ -r etc/aliases ]; then
    if ! grep -q "^%{name}:" etc/aliases; then
        echo "%{name}:	root" >> etc/aliases
        %{logmsg} "Added alias for user %{name} to /etc/aliases"
        if [ -x usr/bin/newaliases ]; then
            usr/bin/newaliases >/dev/null 2>&1 || true
        else
            %{logmsg} "Cannot execute newaliases. Please run it manually."
        fi
    fi
  fi
fi

%if 0%{?using_systemd}
%service_add_post %{name}.service
%fillup_only
%else
%{fillup_and_insserv %{name}}
%endif

%preun
%if 0%{?using_systemd}
%service_del_preun %{name}.service
%else
%stop_on_removal %{name}
%endif

%postun
%if 0%{?using_systemd}
%service_del_postun %{name}.service
%else
%restart_on_update %{name}
%{insserv_cleanup}
%endif

%post www
# If apache is installed, and we can find the apache user, set a shell var
if [ -f etc/apache2/uid.conf ]; then
    wwwusr=$(awk '/^[ \t]*User[ \t]+[a-zA-Z0-9]+/ {print $2}' etc/apache2/uid.conf)
else
    wwwusr=$(awk '/^[ \t]*User[ \t]+[a-zA-Z0-9]+/ {print $2}' etc/apache2/*.conf)
fi
if [ -z "$wwwusr" ]; then # otherwise, use the default
    wwwusr=%{icinga_command_user}
fi
# if apache user is not in cmdgrp, add it
if /usr/bin/id -Gn $wwwusr 2>/dev/null | /bin/grep -q %{icinga_command_group} > /dev/null 2>&1 ; then
    : # $wwwusr (default: %%{icinga_command_user}) is already in %%{icinga_command_group} group
else
    # modify apache user, adding it to cmdgrp
    %if 0%{?suse_version} > 1220
        usermod -a -G %{icinga_command_group} $wwwusr
    %else
        groupmod -A $wwwusr %{icinga_command_group} 2>/dev/null
    %endif
    %{logmsg} "User $wwwusr added to group %{icinga_command_group} so sending commands to Icinga from the command CGI is possible."
fi
if [ ${1:-0} -eq 1 ]
then
    # this is the initial installation: enable icinga
    test -x %{_sbindir}/a2enflag && %{_sbindir}/a2enflag ICINGA >/dev/null
    %if 0%{?using_systemd}
      %{_bindir}/systemctl try-restart apache2
    %else
      %restart_on_update apache2
    %endif
fi

%postun www
if [ "$1" = "0" ]; then
    # deinstallation of the package - remove the apache flag
    test -x %{_sbindir}/a2disflag && %{_sbindir}/a2disflag ICINGA >/dev/null
    %if 0%{?using_systemd}
      %{_bindir}/systemctl try-restart apache2
    %else
      %restart_on_update apache2
    %endif
fi

%post idoutils
%if 0%{?using_systemd}
%service_add_post ido2db.service
%else
%{fillup_and_insserv ido2db}
%endif

if [ ${1:-0} -gt 1 ]
then
# On Update
    %{_defaultdocdir}/%{name}/examples/update_icinga_paths.sh %{name}-idoutils
fi

%{logmsg} "icinga-idoutils installed: Don't forget to install/upgrade your db schema, check /usr/share/doc/packages/icinga-idoutils/README.SUSE.idoutils"

%if 0%{?using_systemd}
%pre idoutils
%service_add_pre ido2db.service
%endif

%preun idoutils
%if 0%{?using_systemd}
%service_del_preun ido2db.service
%else
%stop_on_removal ido2db
%endif

%postun idoutils
%if 0%{?using_systemd}
%service_del_postun ido2db.service
%else
%restart_on_update ido2db
%insserv_cleanup
%endif

%files
%defattr(-,root,root)
%doc README* LICENSE Changelog UPGRADING LEGAL sample-config/ examples
%{_mandir}/man8/icinga*.8*
%{_sbindir}/%{name}
%attr(0755,root,%{icinga_group}) %{_sbindir}/icingastats
%if 0%{?using_systemd}
%attr(0755,root,root) %{_sbindir}/rc%{name}
%{icinga_libdir}/icinga-exec-start-pre
%exclude %{icinga_libdir}/ido2db-exec-start-pre
%{_unitdir}/icinga.service
%else
%{_sbindir}/rc%{name}
%{_initrddir}/%{name}
%endif
%{icinga_datadir}/p1.pl
%{_localstatedir}/adm/fillup-templates/sysconfig.%{name}
%attr(0755,root,root) %config %{_sysconfdir}/cron.weekly/%{name}
%dir %{icinga_libdir}
%dir %{icinga_sysconfdir}
%dir %{icinga_sysconfdir}/modules
%config(noreplace) %{icinga_sysconfdir}/icinga.cfg
%dir %{icinga_sysconfdir}/objects
%dir %{_sysconfdir}/%{name}/conf.d
%config(noreplace) %{icinga_logrotatefile}
%config(noreplace) %{icinga_sysconfdir}/objects/commands.cfg
%config(noreplace) %{icinga_sysconfdir}/objects/contacts.cfg
%config(noreplace) %{icinga_sysconfdir}/objects/notifications.cfg
%config(noreplace) %{icinga_sysconfdir}/objects/localhost.cfg
%config(noreplace) %{icinga_sysconfdir}/objects/printer.cfg
%config(noreplace) %{icinga_sysconfdir}/objects/switch.cfg
%config(noreplace) %{icinga_sysconfdir}/objects/templates.cfg
%config(noreplace) %{icinga_sysconfdir}/objects/timeperiods.cfg
%config(noreplace) %{icinga_sysconfdir}/objects/windows.cfg
%config(noreplace) %attr(0640,icinga,icinga) %{icinga_sysconfdir}/resource.cfg
%defattr(-,%{icinga_user},%{icinga_group})
%dir %{icinga_logdir}
%dir %{icinga_logdir}/archives
%dir %{icinga_localstatedir}
%dir %{icinga_spooldir}
%dir %{icinga_spooldir}/checkresults
%ghost %{icinga_cmd_filedir}

%files -n monitoring-tools
%defattr(-,root,root)
%{_sbindir}/mini_epn
%{_sbindir}/new_mini_epn
%{_mandir}/man8/mini_epn.8*
%{_mandir}/man8/new_mini_epn.8*
%{_mandir}/man8/mini_epn_icinga.8*

%files www
%defattr(-,root,root)
%dir %{icinga_cgidir}/
%{icinga_cgidir}/avail.cgi
%{icinga_cgidir}/cmd.cgi
%{icinga_cgidir}/config.cgi
%{icinga_cgidir}/extinfo.cgi
%{icinga_cgidir}/histogram.cgi
%{icinga_cgidir}/history.cgi
%{icinga_cgidir}/notifications.cgi
%{icinga_cgidir}/outages.cgi
%{icinga_cgidir}/showlog.cgi
%{icinga_cgidir}/status.cgi
%{icinga_cgidir}/statusmap.cgi
%{icinga_cgidir}/summary.cgi
%{icinga_cgidir}/tac.cgi
%{icinga_cgidir}/trends.cgi
%dir %{icinga_datadir}
%{icinga_datadir}/favicon.ico
%{icinga_datadir}/images
%{icinga_datadir}/index.html
%{icinga_datadir}/js
%{icinga_datadir}/main.html
%{icinga_datadir}/media
%{icinga_datadir}/menu.html
%{icinga_datadir}/robots.txt
%{icinga_datadir}/ssi
%{icinga_datadir}/stylesheets
%{icinga_datadir}/jquery-ui
%{icinga_datadir}/jquery-ui-addon
%attr(0775,%{icinga_command_user},%{icinga_command_group}) %dir %{icinga_cgi_logdir}

%files www-config
%defattr(-,root,root,-)
%config(noreplace) %{apacheconfdir}/%{name}.conf
%config(noreplace) %{icinga_sysconfdir}/cgi.cfg
%config(noreplace) %attr(0640,root,%{apachegroup}) %{icinga_http_authfile}

%files idoutils
%defattr(-,root,root)
%doc module/idoutils/db/queries UPGRADING module/idoutils/db/README module/idoutils/config README.SUSE.idoutils
%{_mandir}/man8/ido2db.8*
%{_mandir}/man8/log2ido.8*
%config(noreplace) %{icinga_sysconfdir}/ido2db.cfg
%config(noreplace) %{icinga_sysconfdir}/idomod.cfg
%config(noreplace) %{icinga_sysconfdir}/modules/idoutils.cfg
%config(noreplace) %{icinga_sysconfdir}/modules/flapjack.cfg
%config(noreplace) %{icinga_sysconfdir}/modules/livestatus.cfg
%config(noreplace) %{icinga_sysconfdir}/modules/mod_gearman.cfg
%config(noreplace) %{icinga_sysconfdir}/modules/pnp4nagios.cfg
%config(noreplace) %{icinga_sysconfdir}/objects/ido2db_check_proc.cfg
%{_sbindir}/rcido2db
%if 0%{?using_systemd}
%{_unitdir}/ido2db.service
%{icinga_libdir}/ido2db-exec-start-pre
%else
%{_initrddir}/ido2db
%endif
%{_sbindir}/ido2db
%{_sbindir}/log2ido
%{icinga_libdir}/idomod.so

%files idoutils-mysql
%defattr(-,root,root)
%doc module/idoutils/db/mysql module/idoutils/db/examples

%files idoutils-oracle
%defattr(-,root,root)
%doc module/idoutils/db/oracle

%files idoutils-pgsql
%defattr(-,root,root)
%doc module/idoutils/db/pgsql

%files devel
%defattr(-,root,root)
%{_includedir}/%{name}/

%files doc
%defattr(-,root,root)
%doc %{icinga_datadir}/docs

%files plugins-eventhandlers
%defattr(0755,root,root)
%{icinga_eventhandlerdir}

%files plugins-downtimes
%defattr(0755,root,root)
%{icinga_libdir}/downtimes

%changelog
* Mon Jan  9 2017 thardeck@suse.com
- update to upstream version 1.14.0
  * Classic UI: Remove attribute based authorization (cgiauth.cfg is not parsed anymore)
  * IDO: Remove deprecated config options
  * Feature #3175: Add command "Acknowledge problem for this host and its services"
  * Feature #10684: Help Icinga2 User to use command expansion in Classic-UI
  * Bug #13709: CVE-2016-9566: Root priviledge escalation during log file opening
  * Bug #10453: Icinga Classic-UI 1.13.3 and older are vulnerable to XSS - CVE-2015-8010
  * Bug #882: trends.cgi segfaults
  * Bug #6831: Remove broken attribute-based authorization
  * Bug #9157: Only timestamp and "Return code of 255 is out of bounds" in icinga.log
  * Bug #9409: Add sources for jquery-ui and install minified versions only
  * Bug #9750: Classic UI is showing inaccurate value to retry_interval
  * Bug #9847: max filename length reached for config file paths
  * Bug #10453: Icinga Classic-UI 1.13.3 and older are vulnerable to XSS - CVE-2015-8010
  * Bug #10633: status.cgi doesn't honor host/servicegroup filter once allproblems option is set
  * Bug #11044: configure tries to process obsolete .in file
  * Bug #11048: cgi/cgiutils.c NULL value with segfault in
  * Bug #11221: trends.cgi segfault while reading log files
  * Bug #11732: Classic UI hides menu items (JQuery 1.11, Debian/Ubuntu)
  * Bug #11929: config.cgi notification_period link has a typo
  * Bug #12007: Fix icinga2 Host state notification entries in compat log to interpret states properly
  * Bug #13709: CVE-2016-9566: Root priviledge escalation during log file opening
  * Bug #13745: Spelling errors
  * Bug #13747: make fullinstall doesn't call install-webconf-auth
  * Bug #13749: Update README for icinga.com
- fix icinga source url
* Fri Jun 24 2016 lars@linux-schulserver.de
- package all README files to avoid broken symlink from README to
  README.md
* Wed Jul 15 2015 thardeck@suse.com
- update to upstream version 1.13.3
  * Bug #7337: Only use SCHEDULE_HOST_DOWNTIME command for Icinga 2.x
  * Bug #8130: Wrong values for percent_* when using hostgroup in availability report
  * Bug #9020: Solaris package behaves badly upon uninstall
  * Bug #9106: Icinga no longer sending acknowledgement notifications
  * Bug #9240: invalid JSON for flapping threshold configuration
* Tue May 26 2015 thardeck@suse.com
- prevent changing of tmp_path permissions (bnc#923928)
- update to upstream version 1.13.2
  * Bug #9010: icinga.spec: broken path to downtimes scripts and not packaged config files
* Tue Apr  7 2015 thardeck@suse.com
- update to upstream version 1.13.1
  * Bug #8986: wrong fd initilization preventing checks using file descriptors
* Tue Mar 31 2015 thardeck@suse.com
- update to upstream version 1.13
  * Remove deprecated event_profiling_enabled from icinga.cfg
  * Remove deprecated broker_module from icinga.cfg (use module object configuration instead)
  * Add module config examples in modules/ directory (livestatus, mod_gearman, pnp4nagios, flapjack)
  * Move contrib/downtimes to tools/downtimes and add 'make install-downtimes'
  * Feature #1867: Recurring Downtimes
  * Feature #6353: deprecate icinga.cfg:broker_module; add more module examples
  * Feature #8007: Implement an option to disable transactions
  * Feature #8139: Add functions for registering file descriptors closed on fork()
  * Feature #8140: Add Check Result List Mutex for NEB modules
  * Feature #8426: Remove constraint from *dependencies tables
  * Feature #8440: Enhance idomod logging
  * Bug #6263: Race condition in init.d scripts' stop
  * Bug #6762: Icinga crashes when "args" attribute is not specified for modules
  * Bug #7004: GET form param has no effect on cmd.cgi acks (again)
  * Bug #8202: Cool tip text for refresh of hosts and services says "I'm so lonely up here. Where should I go?"
  * Bug #8441: require the 'config_file' argument in idomod modules configuration
  * Bug #8445: cmd.cgi use_ack_end_time param does not enable tickbox in form
  * Bug #3305: Duplicate service definitions are not generating a config validation error
* Thu Feb 19 2015 thardeck@suse.com
- update to upstream version 1.12.2
  * Bug #3305: Duplicate service definitions are not generating a config validation error
  * Docs - Bug #7801: Add a minified js library for the html docs
* Tue Feb 17 2015 lars@linux-schulserver.de
- fix systemd service alias
* Thu Jan 29 2015 thardeck@suse.com
-update to upstream version 1.12.0
  * core/idoutils: Populate long_output column on notification history neb events #7362 - MF
  * classic ui: start with unhandled problems view instead of TAC #4817 - MF
  * classic ui: Adding alias to title in host/service overview #5900 - WN
  * classic ui: Add display of extra icons in status overview of hosts and services #6829 - RD/RB
  * classic ui: Add config option to set Sticky Acknowledgment checkbox default #6237 - CF
  * classic ui: Add config option to sort status data by default #5965 - RB
  * classic ui: Add sorting of comments and downtimes #5339 - RB
  * classic ui: Add link to online documentation #6606 - RB
  * idoutils: Add program_version column to programstatus table #7390 - MF
  * idoutils: Extend size of column 'alias' for MySQL tables hosts & contacts #6382 - MF
  * idoutils: Import 'is_json' for custom vars into schema (Icinga 2) #7568 - MF
  * classic ui: Fix grammatical errors in popup text #7451 - CF
  * classic ui: Fix order of hosts and service checks in tac.cgi #6965 - RB
  * idoutils: check for undersized data-packets and ignore them to eliminate null transactions to the database #4221 - CF
  * initscript: Correct bash-specific syntax in startup script #7450 - CF
  * spec: Use versioned dependencies in the RPM spec file #7017 - GB
  * core/idoutils: Populate long_output column on notification history neb events #7362
  * idoutils: Add program_version column to programstatus table #7390
  * * required for Icinga Web 2 and Icinga 2
  * idoutils: 'alias' column is now TEXT in MySQL #6382
  * idoutils: Import 'is_json' for custom vars into schema (Icinga 2) #7568
* Wed Jan 28 2015 lars@linux-schulserver.de
- add Alias=monitoring_daemon.service to systemd file to have a
  similar virtual provides like in the old times
- rebased icinga-1.11.7-fix-bashisms.patch
* Sat Dec 20 2014 Led <ledest@gmail.com>
- fix bashism in scripts
- add patches:
  * icinga-1.11.7-fix-bashisms.patch
* Sat Dec 13 2014 Led <ledest@gmail.com>
- fix bashisms in post scripts
* Thu Dec  4 2014 lars@linux-schulserver.de
- use a bash script for rcicinga to integrate some additional
  options from old sysvinit script (check, check_verbose)
* Thu Nov 27 2014 thardeck@suse.com
- remove patch source condition
* Thu Nov 20 2014 thardeck@suse.com
- restrict apache conf patch only to openSUSE 13.1 since it seems to be the only affected version
- renamed icinga-fix-apache-issues-by-using-old-conf.patch to icinga-workaround-131-apache-conf-issue.patch
* Fri Nov 14 2014 thardeck@suse.com
- use icinga-fix-apache-issues-by-using-old-conf.patch only for openSUSE 13.1 and older versions
* Wed Sep  3 2014 thardeck@suse.com
- update to upstream version 1.11.7
  * Use versioned dependencies in the RPM spec file #7071 - GB
  * Import 1.11.7 schema changes from Icinga 2 #6939 - MF
  * New programstatus column 'endpoint_name' requires schema update to 1.11.7! #6939
* Mon Sep  1 2014 thardeck@suse.com
- add util-linux-systemd as build require for newer SUSE distributions (> 13.1)
* Thu Aug  7 2014 thardeck@suse.com
- update to upstream version 1.11.6
  * idoutils: Fix customvariable* tables are not case sensitive (mysql) #6788 - MF
  * installation: Fix misspelled systemd configure options, added hint in Makefile #6710 - SS
  * spec: Add shadow-utils as a dependency for Redhat packaging #4495 - SS
  * spec: Build dependency for "make" is missing - GB
  * Fix comments in cgiutils.c #6712
  * Fix customvariable tables requires schema version update to 1.11.6! #6788
* Tue Jul  8 2014 thardeck@suse.com
- use systemctl to restart Apache on modern distributions
* Tue Jun 24 2014 thardeck@suse.com
- require latest nagios-rpm-macros package to allow building on openSUSE Factory
- make the classic ui package icinga-www independent from Icinga 1
- move config files from the package icinga-www to icinga-www-config
* Fri Jun 20 2014 mardnh@gmx.de
- update to upstream version 1.11.5
  * classic-ui: fix status.cgi gets stuck in loop when sorting on "All Unhandled Problems" #5886 - RB
  * classic ui: Only show command expander if backend is Icinga 1.x (incompatible with Icinga 2) #6408 - MF
  * classic ui: Fix CSRF protection in cmd.cgi matches only compiled in URL #6459 - MF
  * classic-ui: config.cgi missing new option #6502 - RB
  * initscript: Fixed Typo in ido2db and icinga init scripts preventing them to kill -9 their processes #6410 - MaH
  * cgi.cfg: Add url_cgi_path allowing to override the default '$htmurl/cgi-bin' required for CSRF checks #6459
  * * Required for icinga2-classicui Debian package
* Mon Jun  2 2014 thardeck@suse.com
- update to upstream version 1.11.4
  * core: Icinga should warn about deprecated configuration objects and attributes #6075 - MF
  * core: Fix config parser with object custom variables #6330 - MF
  * core: Allow Classic UI config parser to ignore unknown objects #5826 - MF
  * classic ui: Fix jquery.dd source file, update to 2.38 #6324 - MF
  * config parser now marks the following attributes and objects as DEPRECATED (they have been since 0.8.0)
  * * retry_check_interval (hosts, services)
  * * normal_check_internal (hosts, services)
  * * checks_enabled (hosts)
  * * hostextinfo object
  * * serviceextinfo object
* Mon May 12 2014 thardeck@suse.com
- update to upstream version 1.11.3
  * classic ui: add 'is_reachable' attribute to extinfo details (Icinga 2 only) #6186 - MF
  * core: Revert "add colon to illegal_object_name_chars" (#4227) #5931 - MF
  * core: Remove t-tap/ #6022 - MF
  * core: Remove json checker #6023 - MF
  * core: Revert "add colon to illegal_object_name_chars" (#4227) #5931
  * idoutils: Add {host,service}{groups,status] columns: notes, notes_url, action_url, is_reachable. (Icinga 2) #6060
  * * bump schema version to 1.11.3
  * core: Remove json checker
* Thu May  8 2014 thardeck@suse.com
- update to upstream version 1.11.2
  * core: fix regex using servicegroup members *,service fails to expand after lookup (Ricardo Melo) #3881 - MF
  * classic ui: fix parser bailing on command object custom variables (Icinga 2 only) #5940 - MF
  * classic ui: fix CGIs don't work on OS X #5943 - GB
  * classic ui: drop experimental 'check_service' attribute (Icinga 2 only) #5841 - MF
* Mon Apr 14 2014 thardeck@suse.com
- update to upstream version 1.11.1
  * classic ui: add 'check_service' attribute to extinfo details (Icinga 2 only) #5841 - MF
  * classic ui: CVE-2014-2386: fix small buffer overflows when checking strlen against MAX_INPUT_BUFFER (Tim Landscheidt, Wikimedia) #5873 - RB
  * idoutils: oracle: fix missing programstatus config_dump_in_progress #5080 #5776 - TD
  * idoutils: oracle: fix missing symbol for startup schema checks #5777 - TD
  * idoutils: pgsql: fix table creates for icinga 2 endpoints #5850 - GB
* Thu Mar 13 2014 thardeck@suse.com
- removed init services on systemd distributions
- removed obsolete rpmlint entry
- removed man page for convertcfg because it was removed upstream
- update to upstream version 1.11
  * core: add commands for {en,dis}able freshness checks per host/service (Philip Matuskiewicz) #5422 #4430 - MF
  * core: add statehistory entries for newly added services (checkresult with OK state) #3854 - MF
  * core: add option to anonymize external command user in icinga log #5689 - RB
  * classic ui: add status.cgi modifed_attributes filter parameter #4880 - RB
  * classic ui: add "current_notification_number" to jsonoutput of hosts and services in status.cgi #5370 - RB
  * classic ui: add groups Notes and Action URL links to status summary, overview and grid #5301 - RB
  * classic ui: include more logos #4057 - CF/RB
  * classic ui: add Support for gzip compressed logs #4519 - RB
  * idoutils: ido2db should check db schema on startup, and bail early on errors #5272 - MF
  * docs: Define SELinux contexts rather than using chcon command #3555 - WN
  * docs: explain "Check results for service x on host y are stale by 0d 0h 0m 10s (threshold=0d 0h 10m 0s). Forcing an immediate check of the service..." #5252 - WN
  * docs: addons: suggest nsca-ng as nsca alternative #5253 - WN
  * docs: rename nagios plugins to monitoring plugins #5460 - WN/MF
  * core: allow exclude (!) to work for regexp matches for hosts (Franky Van Liedekerke) #5324 - MF
  * core: fix retained host check attempts being 0/1 #5061 - MF
  * core: fix passive check result processing for host checks is not working (Marco Hoyer) #5671 - MF
  * core: fix service escalations with no host mapping are not accepted (Tomas Dubec) #5687 - MF
  * classic ui: getcgivars() fails to produce proper key/value list causing a potential buffer-overflow condition #5276 - CF
  * classic ui: fix vulnerability against CSRF attacks CVE-2013-7107 #5346 - RB
  * classic ui: fix timepicker is resetting time in input field #5239 - RB
  * classic ui: fix small buffer overflows when checking strlen against MAX_INPUT_BUFFER #5663
  * ...
* Wed Feb 19 2014 thardeck@suse.com
- optimized order of icinga-exec-start-pre script
* Tue Feb 18 2014 thardeck@suse.com
- update to upstream version 1.10.3
  * initscript: implement IcingaPrecacheFallback option for the init script (thx Immobilienscout24) #4968 - GB
  * core: fix passive host check commands check service's passive check acceptance (thx Naemon) #5568 - MF
  * core: fix host state translation for passive host check results #5575 - MF
  * classic ui: aggressively check for possible buffer overflows in cmd.cgi (thx GitHub) #5434 - MF
  * classic ui: add missing jquery and jquery-ui-timepicker-addon sources #5564 - MF
  * idoutils: wait for child processes on exit preventing zombies (thx Laurent Bigonville) #4427 - MF
  * initscript: fix ido2db returning invalid lsb codes (Marco Hoyer) #4825 - MF
  * spec: only add apache user to the icingacmd group if existing #5263 - MF
  * spec: fix usermod error on SUSE #5430 - GB
  * spec: backport fedora spec file fixes (thx Fedora & Shawn Starr) #5545 - MF
- add systemd service files on systemd systems (the init scripts will be removed in the future on these systems)
- added icinga-exec-start-pre and ido2db-exec-start-pre scripts to set up the environment before the icinga processes are started by systemd
- added icinga-fix-systemd-services.patch - make sure that the ExecStartPre script are called and there is no need for a separate sysconfig file for the icinga systemd service
- added icinga-fix-apache-issues-by-using-old-conf.patch - Apache 2.4 has issues with the new Icinga apache conf.d file so staying with the old for now
- removed 0001-classic-ui-fix-CVE-2013-7107.patch - because of upstream fix
- removed icinga-fix-create-mysql-script.patch - because of upstream fix
- removed icinga-add-ifdefine-to-apache.patch - superseeded by icinga-fix-apache-issues-by-using-old-conf.patch
- icinga-www now requires icinga-doc to provide the language flag images and documentation
- consistently use spaces instead of tabs in icinga.spec
* Tue Feb  4 2014 thardeck@suse.com
- added 0001-classic-ui-fix-CVE-2013-7107.patch - fixed vulnerability against CSRF attacks CVE-2013-7107 (bnc#859424)
* Thu Jan  9 2014 thardeck@suse.com
- updated the required nagios-rpm-macros version
* Tue Jan  7 2014 thardeck@suse.com
- imported upstream version 1.10.2
  - includes fix for possible denial of service in CGI executables: CVE-2013-7108 (bnc#856837)
  * core: Add an Icinga syntax plugin for Vim #4150 - LE/MF
  * core: Document dropped options log_external_commands_user and event_profiling_enabled #4957 - BA
  * core: type in spec file on ido2db startup #5000 - MF
  * core: Build fails: xdata/xodtemplate.c requires stdint.h #5021 - SH
  * classic ui: fix status output in JSON format not including short and long plugin output properly #5217 - RB
  * classic ui: fix possible buffer overflows #5250 - RB
  * classic ui: fix Off-by-one memory access in process_cgivars() #5251 - RB
  * idoutils: idoutils oracle compile error #5059 - TD
  * idoutils: Oracle update script 1.10.0 failes while trying to drop nonexisting index #5256 - RB
- imported upstream version 1.10.1
  * core: add line number information to config verification error messages #4967 - GB
  * core/idoutils: revert check_source attribute due to mod_gearman manipulating in-memory checkresult list #4958 - MF
  * * classic ui/idoutils schema: functionality is kept only for Icinga 2 support
  * classic ui: fix context help on mouseover in cmd.cgi (Marc-Christian Petersen) #4971 - MF
  * classic ui: correction of colspan value in status.cgi (Bernd Arnold) #4961 - MF
  * idoutils: fix pgsql update script #4953 - AW/MF
  * idoutils: fix logentry_type being integer, not unsigned long (thx David Mikulksi) #4953 - MF
* Mon Dec  2 2013 thardeck@suse.com
- fixed file permission of icingastats - bnc#851619
* Wed Oct 30 2013 lars@linux-schulserver.de
- switch to all unhandled problems per default in index.html
* Tue Oct 29 2013 thardeck@suse.com
- imported upstream version 1.10.0
  * idoutils: slahistory table must be removed manually after enable_sla removal #4363
  - DROP TABLE icinga_slahistory
  * idoutils: timedevents & timedeventqueue tables are deprecated and removed #4482
  * core: allow exclude (!) to work for regexp matches as well (Matthias Kerk) #3720 - MF
  * core: make logging of external command errors more verbose (Anton Lofgren, op5 team) #4402 - MF
  * core: avoid unnecessary ctime() calls when debugging is disabled, increase performance (Opsview Team) #4681 - MF
  * core: add check source to checkresult/status data #4709 - MF
  * core: fix check fails when using environment variables (Sven Nierlein) #2647 - MF
  * classic ui: add display filter modification for status.cgi #852 - RB
  * classic ui: log errors into cgi log (use_logging=1) #4389 - MF
  * classic ui: show custom variables in extended info #4390 - MF
  * classic ui: allow to exclude custom variable name/value based on pattern #4390 - MF
  * classic ui: add make install-classicui-standalone-conf as seperated config installation #4664 - MF
  * classic ui: added performance data to extinfo json output #4728 - RB
  * classic ui: show backend version info from status file (1.x or 2.x) #4737 - MF
  * classic ui: added option for partial servicegroups #2740 - RB
  * classic ui: show check source in extinfo #4709 - MF
  * classic ui: added live search #1657 - Kepi/RB
  * idoutils: add a table trimming option for 'downtime history' #3989 - MF
  * idoutils: allow to disable customvar status updates with dump_customvar_status=0|1 in idomod.cfg #4479 - MF
  * idoutils: add check_source to status tables #4709 - MF
  * idoutils: add object_id (host, service) to logentries status updates/state changes #4754 - MF
  * install: allow enable perfdata config switch via configure #3996 - MF
  * install: add --enable-debug=yes/no to set specific compiler flags for gdb, valgrind #4387 - MF
  * install: detect /etc/apache2/conf-available on debian with apache2.4 #4509 - MF
  * install: add manpages from debian upstream #4055 - MF
* Thu Oct 10 2013 hanke@rzg.mpg.de
- use correct variable for checking the status of the icinga-binary
  in rcicinga
* Sun Sep 22 2013 lars@linux-schulserver.de
- add favicon.ico from Icinga webside to avoid messages in apache
* Mon Sep 16 2013 lars@linux-schulserver.de
- provide and obsolete renamed icinga-monitoring-tools in
  subpackage monitoring-tools
* Wed Sep 11 2013 lars@linux-schulserver.de
- Remove conflicts: nagios for new subpackage monitoring-tools and
  remove the (identical) binaries in Nagios package instead, so
  nagios can recommend the new subpackage as icinga does
- added log2ido manpage
* Thu Sep  5 2013 mls@suse.de
- add libperl_requires, as we link against libperl and thus
  need a specific version of perl
- conflict icinga-monitoring-tools with nagios
* Tue Aug 27 2013 thardeck@suse.com
- updated fix for bnc#834828 to use the default password if none provided
* Tue Aug 27 2013 thardeck@suse.com
- fixed bnc#834828 by asking for the password and changing the log permissions
* Mon Jul  8 2013 thardeck@suse.com
- imported upstream version 1.9.3
  * core: fix init script status exit codes on not running daemon and present pid file #4243 - MF
  * idoutils: fix workaround on libdbi fetch_next_row() bug applied for postgresql too, causing faulty queries #4367 - MF
* Fri Jul  5 2013 thardeck@suse.com
- moved convertcfg, mini_epn and new_mini_epn to the sub package
  icinga-monitoring-tools so that it could be also used by Nagios
* Sun Jun 30 2013 lars@linux-schulserver.de
- update to 1.9.2:
  * core: fix bug with non-ASCII (> 127) illegal macro output
    characters on char-to-int cast (Jason Young) #4211 - MF
  * core: bail early if main config file cannot be read - MF
  * classic ui: fixed searching hostgroup results in wrong 'all'
    view filter urls #4206 - RB
  * classic ui: fix URL construction issue in icinga_reload_scroll_position()
    javascript (Karsten Sühring) #4233 - MF
  * idoutils: fix mysql: output/perfdata limits cut escaped string
    leaving '\' at the end (Yannik Charton) #4196 - MF
  * idoutils: bugfixes for socket queue, transactions and libdbi
    handling #4049 - GB
  * idoutils: fix ido2db gradually consumes more and more CPU time
    with time #4210 - CF
  * idoutils: fix wrong clob freeing in eventhandlers #4357 - TD
* Wed May 22 2013 thardeck@suse.com
- imported upstream version 1.9.1
  * core: fix objects.cache does not get updated on (re)start, but config verify (Christian Ruppert) #4155 - MF
  * classic ui: fixed UNICODE characters in JSON output from getting discarded #4193 - RB
  * idoutils: fix segfaults on reload with multiple neb modules of the same binary #4033 - MF
* Tue May  7 2013 thardeck@suse.com
- imported upstream version 1.9.0 (check the official changelog for further details)
  * idoutils uses a socket queue and transactions for large object dumps! #3527 #3533
  * ido2db.cfg enable_sla is now deprecated! #3450
  * icinga.cfg event_profiling_enabled is now deprecated! #4054
  * core: increase performance with hash comparing hosts/services on config read #3722 - GB
  * core: introduce warning level -vv on config verification #3510 - MF
  * core: refuse to start if neb modules fail to load (Andreas Ericsson, op5 Team) #3812 - MF
  * core: keep logfile open, reducing open/close performance decreases (Andreas Ericsson, op5 Team) #3390 - MF
  * core: enhance illegal macro character processing performance (Andreas Ericsson, op5 Team) #3389 - MF
  * core: add the notification type by string to debug logs; set CUSTOM=8, STALKING=9 (Andreas Ericsson, op5 Team) #3818 - MF
  * core: skip writing status.dat if explicitely set to /dev/null (e.g. when using alternate data retrieval methods like IDOUtils) (Andreas Ericsson, op5 Team) #3819 - MF
  * core: avoid writing objects.cache if set to /dev/null (Andreas Ericsson, op5 Team) #3819 - MF
  * core: increase performance on host->service relation counter (config reading, flapping) #3820 - MF
  * core: fix unable to exclude hostgroups when using nested hostgroups (Alexander Sulfrian) #2619 - MF
  * classic ui: increase performance with hash comparing hosts/services to show/filter #3722 - GB
  * classic ui: Add "set_expire_ack_by_default" to cgi configuration #3476 - CF
  * classic ui: Add "send_ack_notifications" to cgi configuration (TheCry) #3467 - CF
  * classic ui: Changed field size for hours to 4 when setting flexible downtime #3484 - RB
  * ...
* Sun Mar 10 2013 lars@linux-schulserver.de
- move temp_file and temp_dir below /var/run/icinga as this location
  is tmpfs on newer systems which speeds up tempfile creation and
  "handles" the removal during shutdown automatically
- use daemonchk.cgi for "rcicinga status", if possible
* Thu Feb 14 2013 lars@linux-schulserver.de
- provide 'monitoring_daemon' in the init script to allow other
  init scripts to depend on it
* Mon Jan 14 2013 thardeck@suse.com
- imported upstream version 1.8.4
  * core: add fix for CVE-2012-6096 - history.cgi remote command execution (Eric Stanley, Markus Frosch) #3532 - MF
  * classic ui: Changed field size for hours to 4 when setting flexible downtime #3484 - RB
  * classic ui: fixed Warning and Unknown States are mixed up in Alert Summary Report #3488 - RB
  * idoutils: fix empty output/perfdata segfaults for mysql string truncate #3516 - MF
  * idoutils: unlink leftover socket on startup, if using unix sockets - MF
  * idoutils: fix long output data causes wrong data in database #2342 - MF
* Tue Dec 18 2012 crrodriguez@opensuse.org
- Package links to libperl.so so it must use exact perl
  version as requires.
* Mon Dec 17 2012 lars@linux-schulserver.de
- Use usermod instead of groupmod when suse_version > 1220 due to
  pwdutils/shadow switch.
- move macro definition to a place where the macro %%%%name is defined
- added man pages for new_mini_epn, convertcfg and mini_epn
  => conflicts with nagios manpages
* Wed Dec 12 2012 thardeck@suse.com
- imported upstream version 1.8.3
  * idoutils: fix unknown column contactaddress_id (thx fmbiete) #3483 - MF
* Wed Nov 28 2012 thardeck@suse.com
- imported upstream version 1.8.2
  FIXES
  * core: fix macro escaping logs incorrect warning for $$escapes #3404 - MF
  * core: fix wrong escalation notification due to state based escalation range behaviour changes #3441 - MF
  * idoutils: fix many memory leaks in ido2db on dbi_result_free and others (thx Klaus Wagner) #3406 - MF
  * idoutils: fix ido2db crashes when Oracle queries fail #3324 - GB
  * idoutils: fix ORA-1461 writing data to varchar2 exceeding field size limit output, command_arg and commandline data written to Oracle #3324 #3325 - TD
  * idoutils: fix unsafe handling of dbi_conn_sequence_last, rewrite last_insert_id/sequence fetching #3408 - MF
  * idoutils: fix ido2db does not cleanly exit the client on wrong schema version check in db_hello #3419 - MF
  * idoutils: fix FROM_UNIXTIME(NULL) does not work with MySQL 5.0.x #3399 #3466 - CF
  * install: drop unused daemon-init-readhat script (spec uses daemon-init) #3402 - MF
  * install: fix broken configure ssl detection for idoutils on ubuntu/debian (Oliver Skibbe) #3413 - MF
  * classic ui: fix cmd.cgi does not honor commandpipe location; overwrites from empty environment variable #3418 - MF
  * classic ui: fixed double-listed host dependencies in host extinfo.cgi #3295 - RB
  * classic ui: fixed sort_icinga_logfiles_by_name() in readlogs.c fails to take NULL pointers into consideration #3398 - CF
  * classic ui: fixed committing acknowledgement cmd negates flags for send_notification and sticky_ack #3329 - RB
  * classic ui: fixed backtrack_archives only getting calculated on a daily log rotation basis #3416 - RB
  * classic ui: fixed invalid freeing of last_check in 'scheduling queue' for first time checks #3444 - RB
  * docs: add missing cmd_mod description in cgi params #3438 - MF
  * docs: search_string as cgi GET param works also for status.cgi #3451 - MF
  * docs: fix typo pqsql -> pgsql #3461 - WN
  CHANGES
  * icinga.cfg - enable_state_based_escalation_ranges=0 (disabled if not set) fix for #3441
* Tue Nov  6 2012 thardeck@suse.com
- imported upstream version 1.8.1
  * core: fix faulty macro cleaning, replacing spaces with pluses where they shouldn't be cleaned #3397 - MF
* Fri Oct 26 2012 lijewski.stefan@gmail.com
- icingastats is created with 754 (root,icinga) privilegs, cause
  it's mostly running under icinga group
* Thu Oct 18 2012 thardeck@suse.com
- imported upstream version 1.8.0
  * core: pass long_output to neb api for statechange data #2650 - MF
  * core/classic ui: make hashfunc more efficient by using sdbm #2761 - MF/GB
  * core: try the most common macros ($ARGn$, $USERn$) first (Andreas Ericsson) #2674 - MF
  * core: use binary search when looking up macro names, instead of insane strcmp() loops (Andreas Ericsson) #2675 - MF
  * core: add useful message to p1.pl when epn plugin does not call exit() (Sven Nierlein) #2431 -MF
  * core: re-enable state based escalation ranges, using cast tricks #2878 - MF
  * * livestatus and other neb modules not using the icinga headers won't see those
  * core: add a command to disable notifications program-wide with expire time as scheduled event #905 - MF
  * * DISABLE_NOTIFICATIONS_EXPIRE_TIME, works for global notifications
  * core: add hint on icinga.cfg package location, and tip to read Changelog CHANGES on upgrades #2879 - MF
  * core: add new callback NEBTYPE_CONTACTNOTIFICATIONMETHOD_EXECUTE to allow override of sending notifications #2041 - MF
  * core: only reap results when checkresult_list is not overloaded (max_check_result_list_items) (thx Thomas Gelf) #3099 - MF
  * core: log a message when reaper max time is reached #3159 - MF
  * classic ui: Dropped statuswml.cgi #2654 - RB
  * classic ui: Dropped statuswrl.cgi #2359 - RB
  * classic ui: Added action_url/notes_url to status.cgi for csvoutput and jsonoutput #2553 - RB
  * classic ui: Added pagination to various cgi's (thx to ideas and partly source from Nagios, Thruk, Icinga Web) #2725 - RB
  * classic ui: Changed search in config.cgi to regex #2884 - RB
  * classic ui: Added config option to let read-only users see comments and downtimes #2699 - RB
* Thu Oct 11 2012 lars@linux-schulserver.de
- add virtual provides 'monitoring_daemon' and
  'monitoring_webfrontend' to allow 3rd party packages to run also
  with nagios compatible solutions like icinga
* Wed Sep 26 2012 thardeck@suse.com
- added upstream patch to fix the segfault caused by the epn rewrite in #2197 (bnc#780107)
* Mon Aug 27 2012 thardeck@suse.com
- imported upstream version 1.7.2
  * core: fix duplicated events on check scheduling logic for new events (Andreas Ericsson) #2676 #2993 - MF
  * core: avoid duplicate events when scheduling forced host|service check (Imri Zvik) #2993 - MF
  * core: get rid of the instame macro usage while logging alerts and states (Andreas Ericsson) #2665 - MF
  * core: revamp the detection of embedded perl usage directive "# icinga: +epn" (Andreas Ericsson) #2197 - MF
  * core: fix whitespaces are not stripped using multiple templates ("use abc, def, ghi") #2701 - MF
  * core: add hint on icinga.cfg package location, and tip to read Changelog CHANGES on upgrades #2879 - MF
  * core: bail out early with config error if resource.cfg macros contain NULL values #2879 - MF
  * core: fix logical bug on icinga.cfg detection on config read #2879 - MF
  * core: fsync() files before fclose() (Andreas Ericsson) #2948 - MF
  * core: remove weird switch() statement when scanning checkresult queue (Andreas Ericsson) #2950 - MF
  * core: fix deleting too old check result files (Andreas Ericsson) #2951 - MF
  * idoutils: fix icinga mysql db creation script grants access to all dbs #2917 - MF
  * idoutils: fix ignoring mysql password in create_mysqldb.sh #2994 - MF
  * icinga.spec: forced update on icinga.cfg change package locations #2923 -MF
  * icinga.spec: fix permissions on ido2db.cfg potentially world readable (Aaron Russo) #2897 - MF
- removed obsolete create_mysqldb script paches
* Mon Aug 20 2012 thardeck@suse.com
- fixed create_mysqldb script - provided mysql password wasn't passed on
* Thu Aug 16 2012 thardeck@suse.com
- cleaned up init files
* Mon Aug  6 2012 thardeck@suse.com
- reverted icinga home directory change
* Sat Aug  4 2012 thardeck@suse.com
- added missing dependency to the new recurring downtimes plugin
* Fri Aug  3 2012 thardeck@suse.com
- added a new package which provides the recurring downtimes scripts from contrib http://docs.icinga.org/latest/en/recurring_downtimes.html
- updated the icinga user home directory - /var/lib/icinga is not needed anymore
* Wed Jun 20 2012 thardeck@suse.com
- imported upstream version 1.7.1
  * core: use prefix in solaris service definition #2609 - TD/CF
  * core: fix various memory leaks in downtime eventhandling on SIGHUP (Carlos Velasco) #2666 - MF
  * classic ui: Fixed status.cgi time out when displaying hostgroups in large environments #2617 - RB
  * classic ui: Fixed Invalid JSON output for hostgroup overview (Torsten Rehn) #2680 - RB
  * classic ui: Fixed Confusing use of display_name in JSON and CSV output (Torsten Rehn) #2681 - RB
  * classic ui: Fixed wrong totals in "Service Status Summary" on Status Summary page (Mark Ziesemer) #2689 - RB
  * idoutils: fix small compiler issues #2620 - TD/CF
  * idoutils: fix upgradedb script typos & past changes #2682 - MF
  * config: check_ido2db_procs.cfg should not depend on local-service template #2616 - MF
  * install: adapt lsb headers for icinga and ido2db #2637 - MF
  * install: fix typo in contrib/eventhandlers/redundancy-scenario1/handle-master-proc-event (thanks uosiu) #2671 - MF
* Tue Jun 19 2012 thardeck@suse.com
- cleaned up rcicinga and added checkresult directory creation before start
- added patch to fix wrong fsf address in some license files
- extracted update_path_script parts from %%post to a separate file located under doc
* Fri Jun 15 2012 thardeck@suse.com
- fixed icinga-create_mysqldb.sh - it granted icinga access to all dbs - so please check the permissions of your mysql icinga user
- removed all other ido2utils scripts since they are not supported by upstream
- updated readme - better distinguishable topics
* Fri Jun 15 2012 thardeck@suse.com
- updated readme - mysql example command granted icinga access to all dbs
* Wed Jun 13 2012 lars@linux-schulserver.de
- added 'show-errors' to icinga init script as documented in the
  wiki
* Tue Jun  5 2012 thardeck@suse.com
- changed eventhandlers directory from /usr/lib/nagios/plugins/eventhandler to /lib/icinga/eventhandler (unpackaged files do not get copied)
- moved remaining files and the checkresults directory from /var/lib/icinga to /var/spool/icinga
- moved /var/lib/icinga to /var/spool/icinga/
- removed nagios directories from the packages (/var/lib/nagios/*)
- changed /var/spool/icinga/icinga.cmd to /var/run/icinga/icinga.cmd
- changed /var/spool/icinga/ido2db.sock to /var/run/icinga/ido2db.sock
- added post scripts to update the existing configuration files accordingly
- replaced the existing default http-passwd file with the one from upstream - user icingaadmin with password icingaadmin
- adapted the RHEL upstream icinga and icinga-idoutils readmes for SUSE and packaged them
- idoutils db schema has changed, check /usr/share/doc/packages/icinga-idoutils/README.SUSE.idoutils how to upgrade it
- imported upstream version 1.7.0
  * core: notifications: Create contact list after eventbroker callbacks (Andreas Ericsson) #2110 - MF
  * core: fix event removal from queues with O(1) removal from doubly linked lists (Andreas Ericsson) #2183 - MF
  * core: avoid senseless looping when free()'ing macros (Andreas Ericsson) #2184 - MF
  * core: avoid insane looping through event list when rescheduling checks (Mathias Kettner, Andreas Ericsson) #2182 - MF
  * core: allow empty host groups in service and host dependencies if allow_empty_hostgroup_assignment flag is set (Daniel Wittenberg) #2255 - MF
  * core: fix compatibility problems on solaris 10 (affects core, cgis, ido) (Carl R. Friend) #2292 - MF/RB/TD
  * core: add trigger_time to downtimes to allow calculating of flexible downtimes endtime #2537 - MF
  * core: add nebmodule version/name check for idomod (this allows future version dependencies) #2569 - MF
  * classic ui: Added option for max log entries displayed in showlog.cgi #2145 - RB
  * classic ui: Added config option for status totals in status.cgi #2018 - RB
  * classic ui: Added multiple hosts/services to status.cgi GET #1981 - RB
  * classic ui: Added nostatusheader in status.cgi as config option #2018 - RB
  * classic ui: Added statusmap resizing with exclude/include button (thanks to Mat) #2186 - RB
  * classic ui: Added Select hosts or services by clicking on line instead of box #2118 - RB
  * classic ui: include graph icons by default in logos #2222 - MF
  * classic ui: added missing comment tool tip box to outages.cgi #2396 - RB
  * classic ui: add javascript to refresh page/pause easier #2119 - RB
  * classic ui: Added Scheduling queue filter for specific host or service #2421 - RB
  * classic ui: add display_status_totals as cgi.cfg option in order to allow the status totals to be shown again #2443 - RB
  * classic ui: Changed reading of auth information from cgiauth.c to cgiutils.c #2524 - RB
  * classic ui: Added readonly cgi.cfg view into the config section #1776 - RB
  * classic ui: add is_in_effect and trigger_time to downtime view for html, csv, json #2538 - MF
  * classic ui: add modified attributes row to extinfo.cgi showing diffs to original config (thx Sven Nierlein for the idea) #2473 - MF
  * classic ui: add modified attributes reset command to extinfo.cgi allowing to reset to original config #2474 - MF
  * idoutils: add new index for state in table statehistory #2274 - TD
  * idoutils: add is_in_effect and trigger_time to scheduleddowntime and downtimehistory tables #2539 - MF
  * idoutils: change varchar(255) to TEXT in mysql (not cs and address rfc columns) #2181 - MF
  * idoutils: enhance dbversion table with modified and created columns #2562 - MF
  * idoutils: set module info in idomod, to be checked on neb module load in future versions #2569 - MF
* Sun May 27 2012 lars@linux-schulserver.de
- init script: check configuration before restart to avoid a
    non running service on config problems
* Fri Mar  2 2012 thardeck@suse.com
- Changed the spec file to use the nagios-rpm-macro variables
- Fixed a rare bug in rcido2db when the pid directory was missing during first start
* Tue Feb 21 2012 thardeck@suse.com
- Added changelog entry about the icinga-api removal
* Thu Feb 16 2012 saschpe@suse.de
- Added some detail about the last version updates
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Fri Dec  2 2011 thardeck@suse.com
- Imported Upstream version 1.6.1:
  * core: fix freshness checks are generating stale alerts, even
    if result was received in time
* Thu Dec  1 2011 thardeck@suse.com
- imported Upstream version 1.6.0
  * package: complete remove icinga-api as module #1935
  * * Development is being discontinued for now, 1.5.0 was last combined release.
  * core: fix downtime and comments delete with wrong loop pointers
    causing segfaults
  * core: fix $NOTIFICATIONRECIPIENTS$ macro contains all contacts
    assigned to host|service, not only notified contacts
  * core: plug memory leak in downtimes comment add
  * core: make first_notification_delay depend on the first !OK hard state
    change and don't reset timer for new hard states which would replace it
  * core: fix memory leak in xodtemplate.c
  * classic ui: fix for Classic-UI displays bad timeperiods
  * classic ui: fixed wrong color in histogram and trends for unknown/unreachable
  * classic ui: fixed search not returning all results, only first match
  * classic ui: fixed wrong output from status.cgi with option hostservicedetail
  * classic ui: fix typo in histogram.c
  * idoutils: host state change last_hard_state overrides last_state,
    last_hard_state always -1
  * idoutils: extend conninfo.agent_version field  to varchar(16)
  * idoutils: terminate threads cleanly, including db connection
  * install: rework the version updates in icinga and idoutils
  - See ChangeLog for more details
* Thu Oct 13 2011 coolo@suse.com
- remove fragile service
* Wed Oct  5 2011 thardeck@suse.com
- fixed incorrect rcicinga meta data
* Tue Sep 20 2011 thardeck@suse.com
- imported Upstream version 1.5.1
- ran spec-cleaner and added patch tags
* Thu Sep 15 2011 thardeck@suse.com
- removed unnecessary testing source files because of conflicting licenses
- little spec file optimizations
* Fri Sep  9 2011 thardeck@suse.com
- cleaned up icinga.spec
- removed specs for other distributions
* Fri Sep  2 2011 thardeck@suse.com
- made icinga-api building optional but disabling it by default
  just set build_api to 1 to build the packages
* Sun Aug 28 2011 thardeck@suse.com
- removed obsolete icinga-api
- added icinga-remove-api.patch
- little spec file optimizations
* Sat Aug 27 2011 thardeck@suse.com
- initial version 1.5.0
- removed obsolete patch with-p1-file-dir
* Mon Jul 11 2011 thardeck@suse.com
- activated Fedora 15
* Mon Jul 11 2011 thardeck@suse.com
- initial version 1.4.2
- added 1.5 with-p1-file-dir.patch
- created new ido2db init script
- updated icinga init script (no spool sgid needed anymore)
- major spec file changes
- fixed wrong var pathes
* Mon Jul 11 2011 lars@linux-schulserver.de
- changed cron job according to bnc#701208
* Tue Jun 21 2011 thardeck@suse.com
- remove ido2db lock and socket files while stopping the init script
* Fri Jun 17 2011 thardeck@suse.com
- using the Build Service SourceService for the tarball
- using the default spec for other distributions
* Thu Jun  9 2011 thardeck@suse.com
- added db update notification for idoutils
* Wed Jun  8 2011 thardeck@suse.com
- initial version 1.4.1
* Fri May 20 2011 thardeck@suse.com
- reverted idoutils db path
* Fri May 20 2011 thardeck@suse.com
- fixed a wrong cmd configuration entry
- fixed some rpmlint warnings
* Thu May 19 2011 thardeck@suse.com
- initial version 1.4.0
- removed db creation scripts - 1.4.0 has its own now
- removed openssl patch - now obsolete
* Fri May  6 2011 thardeck@suse.com
- SLES 10 Perl issue fixed
* Fri May  6 2011 thardeck@suse.com
- added fix for ssl support and enabled it
- updated mysql db creation script
- fixed some rpmlint warnings
* Thu Mar 31 2011 thardeck@suse.com
- initial version 1.3.1
* Thu Mar  3 2011 thardeck@suse.com
- fixed ido2db db initializiation scripts
- fixed /var/run/spool/icinga permissions
* Mon Feb 28 2011 thardeck@suse.com
- fixed SLES 10 building problem
- fixed empty file warnings
* Mon Feb 28 2011 thardeck@suse.com
- fixed icinga-api permissions
- replaced the ido2db init script with a basic version because of problems
- added simple db creation script for mysql and pgsql for idoutils
- moved icinga-api docs to icinga-api-doc
- fixed idoutils oracle dependency
* Tue Feb 22 2011 lars@linux-schulserver.de
- fix pathname to database in icinga-installdb
- require perl(DBD::mysql) in icinga-idoutils-mysql
* Sat Feb 19 2011 lars@linux-schulserver.de
- package documentation and SQL statements in
  /usr/share/doc/packages/icinga-idoutils-{mysql,postgresql}
- create two subpackages icinga-idoutils-{mysql,postgresql} for
  the two supported databases
- also package php files in %%{_datadir}/%%{name}/icinga-api/
* Fri Feb 18 2011 thardeck@suse.com
- initial version 1.3.0
- fixed ido2db init script removal problem
- fixed some warnings
* Mon Feb 14 2011 lars@linux-schulserver.de
- enable ICINGA via a2enflag on initial installation
* Mon Feb 14 2011 lars@linux-schulserver.de
- install icinga.conf instead of icinga.conf.in and add an
  <IfDefine ICINGA>, so users can enable the apache configuration
  via /etc/sysconfig/apache2 (APACHE_SERVER_FLAGS="ICINGA")
* Sat Feb 12 2011 lars@linux-schulserver.de
- fix path to traceroute
- split off different packages:
  + icinga-doc
  + icinga-api
  + icinga-plugins-eventhandlers
- patch (mini-)epn to use full path to p1.pl
- add Requires/Recommends to packages
* Sun Feb  6 2011 lars@linux-schulserver.de
- fix ido2db init script
- fix non_void function
- add rpmlintrc
- place the apache config file in /etc/apache2/conf.d/ and mark it
  as not included by default
- added manpages from Debian
- move p1.pl to /usr/sbin
- added pre/post scripts for idoutils
* Thu Nov 11 2010 lars@linux-schulserver.de
- initial version 1.2.1 based on nagios package
